@@ -37,8 +37,6 @@ def __connect():
     Connect to a redis instance.
     """
     global redis_instance
-    if redis_instance is not None:
-        return
     if use_tcp_socket:
         redis_instance = redis.StrictRedis(host=hostname, port=port)
     else:
@@ -52,7 +50,8 @@ def log(level, message):
     :param level: the level of the message
     :param message: the message you want to log
     """
-    __connect()
+    if redis_instance is None:
+        __connect()
 
     if level not in __error_levels:
         raise InvalidErrorLevel('You have used an invalid error level. \
