@@ -41,7 +41,7 @@ smtp_port = 0
 src_server = None
 
 
-def setup(name, path='log', enable_debug=False, syslog=False, syslog_address=None):
+def setup(name, path='log', enable_debug=False, syslog=False, syslog_address=None, syslog_facility='user', syslog_level='WARNING'):
     """
     Prepare a NestedSetup.
 
@@ -52,7 +52,9 @@ def setup(name, path='log', enable_debug=False, syslog=False, syslog_address=Non
     :return a nested Setup
     """
     path_tmpl = os.path.join(path, '{name}_{level}.log')
+    debug = path_tmpl.format(name=name, level='debug')
     info = path_tmpl.format(name=name, level='info')
+    notice = path_tmpl.format(name=name, level='notice')
     warn = path_tmpl.format(name=name, level='warn')
     err = path_tmpl.format(name=name, level='err')
     crit = path_tmpl.format(name=name, level='crit')
@@ -85,9 +87,25 @@ def setup(name, path='log', enable_debug=False, syslog=False, syslog_address=Non
             address = syslog_address
         else:
             address = None
-        setup.append(SyslogHandler(warn, address=address, level='WARNING'))
-        setup.append(SyslogHandler(err, address=address, level='ERROR'))
-        setup.append(SyslogHandler(crit, address=address, level='CRITICAL'))
+
+        activate_other_level = False
+        if syslog_level == 'DEBUG':
+            setup.append(SyslogHandler(debug, address=address, facility=syslog_facility, level='DEBUG'))
+            activate_other_level = True
+        if syslog_level == 'INFO' or activate_other_level:
+            setup.append(SyslogHandler(info, address=address, facility=syslog_facility, level='INFO'))
+            activate_other_level = True
+        if syslog_level == 'NOTICE' or activate_other_level:
+            setup.append(SyslogHandler(notice, address=address, facility=syslog_facility, level='NOTICE'))
+            activate_other_level = True
+        if syslog_level == 'WARNING' or activate_other_level:
+            setup.append(SyslogHandler(warn, address=address, facility=syslog_facility, level='WARNING'))
+            activate_other_level = True
+        if syslog_level == 'ERROR' or activate_other_level:
+            setup.append(SyslogHandler(err, address=address, facility=syslog_facility, level='ERROR'))
+            activate_other_level = True
+        if syslog_level == 'CRITICAL' or activate_other_level:
+            setup.append(SyslogHandler(crit, address=address, facility=syslog_facility, level='CRITICAL'))
 
     if src_server is not None and smtp_server is not None \
             and smtp_port != 0 and len(dest_mails) != 0:
@@ -121,7 +139,7 @@ def mail_setup(path):
     src_server = config.get('mail', 'src_server')
 
 
-def run(log_name, path, debug=False, mail=None, syslog=False, syslog_address=None, timeout=0):
+def run(log_name, path, debug=False, mail=None, syslog=False, syslog_address=None, syslog_facility='user', syslog_level='warning', timeout=0):
     """
     Run a subscriber and pass the messages to the logbook setup.
     Stays alive as long as the pubsub instance listen to something.
@@ -153,7 +171,7 @@ def run(log_name, path, debug=False, mail=None, syslog=False, syslog_address=Non
         raise Exception("The path you want to use to save the file is invalid (not a directory).")
     if not os.path.exists(path):
         os.mkdir(path)
-    with setup(channel, path, debug, syslog, syslog_address):
+    with setup(channel, path, debug, syslog, syslog_address, syslog_facility, syslog_level):
         while True:
             msg = pubsub.get_message()
             if msg:
